<?php
/** Hausa (هَوُسَ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Mladanali
 */

$messages = array(
# User preference toggles
'tog-underline'               => 'A shaya zaruruwa',
'tog-highlightbroken'         => 'A haskaka katsattsin zaruruwa <a href="" class="new">kamar haka</a> (koko: kamar haka<a href="" class="internal">?</a>)',
'tog-justify'                 => 'A daidaita sakin layuka',
'tog-hideminor'               => 'A ɓoye ƙananan gyare-gyare na baya-bayan nan',
'tog-hidepatrolled'           => 'A ɓoye gyare-gyaren kan ido a cikin gyare-gyare bayan-bayan nan',
'tog-newpageshidepatrolled'   => 'A ɓoye shafuna kan ido a cikin sabbin shafuna',
'tog-extendwatchlist'         => 'A faɗaɗa jerin kan ido ya nuna duka gyare-gyare, ba na baya-bayan nan kawai ba',
'tog-usenewrc'                => 'A yi amfani da kyautattun gyare-gyare na baya-bayan nan (ana buƙatar Javascript)',
'tog-numberheadings'          => 'A lambace kanun matani kai tsaye',
'tog-showtoolbar'             => 'A nuna sandar kayan aiki ta gyarawa (ana buƙatar JavaScript)',
'tog-editondblclick'          => 'A gyara shafuna da dabar-kiliki (ana buƙatar JavaScript)',
'tog-editsection'             => 'A lamunta gyara sashe ta hanyar zaruruwan [gyarawa]',
'tog-editsectiononrightclick' => 'A lamunta gyara shashe da kilikin dama a kan kanun shashe (ana buƙatar JavaScript)',
'tog-showtoc'                 => 'A nuna jadawalin kanu (cikin shafuna masu fiye da kanu 3)',
'tog-rememberpassword'        => 'A adana bayanan loginkina a wannan kwamfyuta (for a maximum of $1 {{PLURAL:$1|day|days}})',
'tog-watchcreations'          => 'A daɗa shafunan da na ƙirƙira a cikin jerina na kan ido',
'tog-watchdefault'            => 'A daɗa shafunan da na gyara a cikin jerina na kan ido',
'tog-watchmoves'              => 'A daɗa shafunan da na gusar a cikin jerina na kan ido',
'tog-watchdeletion'           => 'A daɗa shafunan da na shafe a cikin jerina na kan ido',
'tog-minordefault'            => 'A alamta gyare-gyarena a matsayin ƙanana bisa manufa',
'tog-previewontop'            => 'A nuna filin rigya-gani sama ga filin gyare-gyare',
'tog-previewonfirst'          => 'A nuna rigya-gani tun gyaran farin',
'tog-nocache'                 => 'A tsayar da kacin shafi',
'tog-enotifwatchlistpages'    => 'A shaida mani ta Imel idan wani shafin jeerina na bin-sau ya sauya',
'tog-enotifusertalkpages'     => 'A shaida mani ta Imel idan shafina na muhawara ya sauya',
'tog-enotifminoredits'        => 'A shaida mani ta Imel game da ko da ƙaramin gyara ne',
'tog-enotifrevealaddr'        => "A bayyana Imel kina a cikin sak'wanni na shaidarwa",
'tog-shownumberswatching'     => "A nuna adadin ma'aikata masu bin sawun wannan shafi",
'tog-oldsig'                  => 'Rigya-ganin sa-hannu da ake da shi',
'tog-fancysig'                => 'A ɗauki matanin sa-hannu a matsayin matanin Wiki (ba tare da mahaɗin otomatik ba)',
'tog-externaleditor'          => 'Bisa manufa, a yi amfani da editan matani daban (zuwa ga ƙwararri: kuna buƙatar sauya saitin kwamfyutarku)',
'tog-externaldiff'            => 'Bisa manufa, a yi amfani da kwatantau daban (zuwa ga ƙwararri: kuna buƙatar sauya saitin kwamfyutarku)',
'tog-showjumplinks'           => 'A lamunta mahaɗan "a tsallaka zuwa"',
'tog-uselivepreview'          => 'A yi amfani da rigya-gani mai sauƙi (ana buƙatar JavaScript) (hajar gwaji)',
'tog-forceeditsummary'        => 'A gargaɗe ni idan na ajiye kangon fili na taƙaitawa',
'tog-watchlisthideown'        => 'A ɓoye sauye-sauyena daga jerin bin sawu',
'tog-watchlisthidebots'       => 'A ɓoye sauye-sauye da rabuwatoci suka daga jerin bin sawu',
'tog-watchlisthideminor'      => 'A ɓoye ƙananen sauye-sauye daga jerin bin sau',
'tog-watchlisthideliu'        => "A ɓoye sauye-sauyen da logaggin ma'aikata suka yi daga jerin bin sau",
'tog-watchlisthideanons'      => "A ɓoye sauye-sauyen da ma'aikata maras suna suka yi daga jerin bin sau",
'tog-watchlisthidepatrolled'  => 'A ɓoye sauye-sauye da ke kan lura daga jerin bin sau',
'tog-ccmeonemails'            => "A aika mini kwafi na duk imel da nike aikawa wasu ma'aikata",
'tog-diffonly'                => 'Kada a nuna tsarabar shafuna a ƙarƙashin sakamakon kwatance',
'tog-showhiddencats'          => 'A nuna rukunonin ɓoye',
'tog-norollbackdiff'          => 'Kada a nuna sauyi da aka yi idan aka banye shi',

'underline-always'  => 'Kullum',
'underline-never'   => 'Ko kaɗan',
'underline-default' => 'Manufar buroza',

# Font style option in Special:Preferences
'editfont-style'     => 'Salon fanti na filin gyara',
'editfont-default'   => 'Manufar buroza',
'editfont-monospace' => 'Fanti mai tsayayyen faɗi',
'editfont-sansserif' => 'Fanti maras sarif',
'editfont-serif'     => 'Fanti mai sarif',

# Dates
'sunday'        => 'Lahadi',
'monday'        => 'Litinin',
'tuesday'       => 'Talata',
'wednesday'     => 'Laraba',
'thursday'      => 'Alhamis',
'friday'        => "Jumma'a",
'saturday'      => 'Asabar',
'sun'           => 'Lah',
'mon'           => 'Lit',
'tue'           => 'Tal',
'wed'           => 'Lar',
'thu'           => 'Alh',
'fri'           => 'Jum',
'sat'           => 'Asa',
'january'       => 'Janairu',
'february'      => 'Faburairu',
'march'         => 'Maris',
'april'         => 'Afirilu',
'may_long'      => 'Mayu',
'june'          => 'Yuni',
'july'          => 'Yuli',
'august'        => 'Agusta',
'september'     => 'Satumba',
'october'       => 'Oktoba',
'november'      => 'Nuwamba',
'december'      => 'Disamba',
'january-gen'   => 'Janairu',
'february-gen'  => 'Faburairu',
'march-gen'     => 'Maris',
'april-gen'     => 'Afirilu',
'may-gen'       => 'Mayu',
'june-gen'      => 'Yuni',
'july-gen'      => 'Yuli',
'august-gen'    => 'Agusta',
'september-gen' => 'Satumba',
'october-gen'   => 'Oktoba',
'november-gen'  => 'Nuwamba',
'december-gen'  => 'Disamba',
'jan'           => 'Jan',
'feb'           => 'Fab',
'mar'           => 'Mar',
'apr'           => 'Afi',
'may'           => 'May',
'jun'           => 'Yun',
'jul'           => 'Yul',
'aug'           => 'Agu',
'sep'           => 'Sat',
'oct'           => 'Okt',
'nov'           => 'Nuw',
'dec'           => 'Dic',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Rukuni|Rukunoni}}',
'category_header'        => 'Shafuna na cikin rukunin "$1"',
'subcategories'          => 'Ƙananan rukunoni',
'hidden-categories'      => '{{PLURAL:$1|Ɓoyayyen rukuni|Ɓoyayyun rukunoni}}',
'category-subcat-count'  => '{{PLURAL:$2|Wannan rukuni ya ƙumshi wannan ƙaramin rukuni kawai.|Wannan rukuni ya ƙumshi {{PLURAL:$1|wannan ƙaramin rukuni|$1 wanɗannan ƙananan rukunoni}}, daga cikin jimlar $2.}}',
'category-article-count' => '{{PLURAL:$2|Wannan rukuni ya ƙumshi wannan shafi kawai.|{{PLURAL:$1|shafi na gaba yana|$1 shafuna na gaba suna}} cikin wannan rukuni, daga cikin jimlar $2.}}',
'listingcontinuesabbrev' => 'ci-gaba',

'newwindow'  => '(buɗa cikin sabuwar taga)',
'cancel'     => 'Soke',
'mytalk'     => 'Mahawarata',
'navigation' => 'Shawagi',

# Cologne Blue skin
'qbfind'         => 'Nemo',
'qbedit'         => 'Gyarawa',
'qbspecialpages' => 'Shafuna na musamman',

# Vector skin
'vector-action-delete'  => 'Soke',
'vector-action-move'    => 'Gusarwa',
'vector-action-protect' => 'A kare',
'vector-view-create'    => 'Ƙirƙira',

'errorpagetitle'   => 'Tangarɗa',
'returnto'         => 'Koma $1',
'tagline'          => 'Daga {{SITENAME}}',
'help'             => 'Taimako',
'search'           => 'Nema',
'searchbutton'     => 'Binciko',
'searcharticle'    => 'Mu je',
'history'          => 'Tarihin shafi',
'history_short'    => 'Tarihi',
'printableversion' => 'Sufar bugawa',
'permalink'        => 'Dawwamammen mahaɗi',
'edit'             => 'Gyarawa',
'create'           => 'Ƙirƙira',
'editthispage'     => 'Gyara wanna shafi',
'delete'           => 'Soke',
'protect'          => 'A kare',
'protect_change'   => 'sauyawa',
'newpage'          => 'Sabon shafi',
'talkpage'         => 'Muhawara kan wannan shafi',
'talkpagelinktext' => 'Hira',
'personaltools'    => 'Zaɓaɓɓin kayan aiki',
'talk'             => 'Mahawara',
'views'            => 'Hange',
'toolbox'          => 'Akwatin kayan aiki',
'otherlanguages'   => 'A wasu harsuna',
'redirectedfrom'   => '(an turo daga $1)',
'redirectpagesub'  => 'Shafin turawa',
'lastmodifiedat'   => 'Gyaran baya na wannan shafi ran $1, a $2.',
'jumpto'           => 'A tsallaka zuwa:',
'jumptonavigation' => 'Shawagi',
'jumptosearch'     => 'nema',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'      => 'Game da {{SITENAME}}',
'aboutpage'      => 'Project:Game da',
'copyright'      => 'Bayannai sun samu a ƙarƙashin $1.',
'copyrightpage'  => '{{ns:project}}:Hakkin Mallaka',
'disclaimers'    => 'Hattara',
'disclaimerpage' => 'Project:Babban gargaɗi',
'edithelp'       => 'Taimako kan gyara',
'edithelppage'   => 'Help:Gyarawa',
'helppage'       => 'Help:Tsaraba',
'mainpage'       => 'Marhabin',
'privacy'        => 'Manufar kare sirri',
'privacypage'    => 'Project:Manufar kare sirri',

'badaccess' => 'Tangarɗar lamuncewa',

'retrievedfrom'       => 'Daga "$1"',
'youhavenewmessages'  => 'Kuna da $1 ($2).',
'newmessageslink'     => 'sabbin saƙonni',
'newmessagesdifflink' => 'sauyin ƙarshe',
'editsection'         => 'gyarawa',
'editold'             => 'gyarawa',
'editlink'            => 'gyarawa',
'viewsourcelink'      => 'duba tushe',
'editsectionhint'     => 'Gyara sashe: $1',
'toc'                 => 'Kanun bayannai',
'showtoc'             => 'nuna',
'hidetoc'             => 'ɓoye',
'site-rss-feed'       => 'Kwararen RSS na $1',
'site-atom-feed'      => 'Kwararen Atom na $1',
'page-rss-feed'       => 'Kwararen RSS na "$1"',
'page-atom-feed'      => 'Kwararen Atom na "$1"',
'red-link-title'      => '$1 (babu wannan shafi)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Shafi',
'nstab-user'     => "Shafin ma'aikaci",
'nstab-special'  => 'Shafi na musamman',
'nstab-project'  => 'Shafin shiri',
'nstab-image'    => 'Fayil',
'nstab-template' => 'Mulu',
'nstab-category' => 'Rukuni',

# General errors
'missing-article'    => 'Taskar bayannai ba ta samo matanin wani shafin da ya kamata ta samo ba, mai suna "$1" $2.

Mafarin haka yawanci shi ne mahaɗi mai zuwa ga shafin da aka soke ko aka gusar.

In ba haka ba ne, to kun takalo wata tangarɗa a safuwai kin.
Don Allah a aika ruhoto zuwa ga [[Special:ListUsers/sysop|administrator]], tare da nuna URL kin.',
'missingarticle-rev' => '(lambar zubi: $1)',
'badtitletext'       => "Kan shafin da aka nema bai da ma'ana, ko kango ne, ko kuma wani kai ne na tsakanin harsuna ko shire-shire da bai da mahaɗi mai kyau.
Tana yiyuwa yana da harafi ko haruffa da ba su karɓuwa cikin kanu.",
'viewsource'         => 'Duba tushe',

# Login and logout pages
'yourname'                => "Sunan ma'aikaci:",
'yourpassword'            => 'Kalmar sirri:',
'remembermypassword'      => 'Adana bayannan logina a wannan kwafyuta (for a maximum of $1 {{PLURAL:$1|day|days}})',
'login'                   => 'Logi',
'nav-login-createaccount' => 'logi / sabon akwanti',
'userlogin'               => 'Logi / sabon akwanti',
'logout'                  => 'Ban kwana',
'userlogout'              => 'Ban kwana',
'nologinlink'             => 'Buɗa sabon akwanti',
'createaccountreason'     => 'Dalili:',
'mailmypassword'          => 'Aiken kalmar sirri ta Imel',

# Change password dialog
'resetpass-submit-cancel' => 'Soke',

# Edit page toolbar
'bold_sample'     => 'Rubutu mai gwaɓi',
'bold_tip'        => 'Rubutu mai gwaɓi',
'italic_sample'   => 'Rubutun tsutsa',
'italic_tip'      => 'Rubutun tsutsa',
'link_sample'     => 'Sunan mahaɗi',
'link_tip'        => 'Mahaɗin ciki',
'extlink_sample'  => 'http://www.example.com sunan mahaɗi',
'extlink_tip'     => 'Mahaɗi mai zuwa waje (a tuna da zagin http://)',
'headline_sample' => 'Sunan kai',
'headline_tip'    => 'Kan mataki na 2',
'nowiki_sample'   => 'shigar da ɗanyen rubutu a nan',
'nowiki_tip'      => 'Kawar da sufantawar Wiki',
'image_tip'       => 'Ƙumsashen fayil',
'media_tip'       => 'Mahaɗi zuwa fayil',
'sig_tip'         => 'Sa-hannunku da dagin rana',
'hr_tip'          => 'Layin kwance',

# Edit pages
'summary'                          => 'Taƙaici:',
'subject'                          => 'Jigo/Kai:',
'minoredit'                        => 'Ƙaramin gyara',
'watchthis'                        => 'Bi sawun wannan shafi',
'savearticle'                      => 'Adana shafi',
'preview'                          => 'Rigya-gani',
'showpreview'                      => 'Sufar rigya-gani',
'showdiff'                         => 'Nuna sauye-sauye',
'anoneditwarning'                  => "'''Hattara:''' Ba ku yi logi ba.
Za a rubuta adireshinku na IP a cikin tarihin sauye-sauyen wannan shafi.",
'summary-preview'                  => 'Rigya-gani na taƙaici:',
'newarticle'                       => '(Sabo)',
'newarticletext'                   => "Kun latsa mahaɗi zuwa shafin da babu shi tukuna.
Domin ƙirƙiro wannan shafin, ku fara rubutu a cikin fage na ƙasa (duba [[{{MediaWiki:Helppage}}|shafin taimako]] don ƙarin bayani).
Idan kun ɓata ne cikin shawaginku, to ku latsa maɓallin '''baya''' na safuwayan shawaginku.",
'noarticletext'                    => 'A halin yanzu babu matani a kan wannan shafi.
Kuna iya [[Special:Search/{{PAGENAME}}|nemo kan wannan shafi]] cikin wasu shafuna,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} bincika rajistan ayyukan],
ko [{{fullurl:{{FULLPAGENAME}}|action=edit}} gyara wannan shafi]</span>.',
'previewnote'                      => "'''Kada ku manta, wannan rigya-gani ne kawai.'''
Ba a adana sauye-sauyenku ba tukuna!",
'editing'                          => 'Gyaran $1',
'editingsection'                   => 'Gyaran $1 (sashe)',
'copyrightwarning'                 => "Lura cewa ana wallafa duk gudummuwa ga {{SITENAME}} a kan ƙa'idojin \$2 (duba \$1 don ƙarin bayani). Idan ba kwa son a sauya ko a rarraba ayyukanku yadda aka ga dama, to kada ku ajiye su a nan.<br />
Kuma kuna mana alƙawarin cewa ku ne kuka rubuta aikin, ko kun juyo shi daga hajar kowa (wato \"public domain\"), ko kuma aikin hajar kyauta (wato \"free resource\") ne. '''Kada ku ajiye ayyuka masu hakkin mallaka ba tare da izini ba!'''",
'templatesused'                    => '{{PLURAL:$1|Mulun da aka yi amfani da shi|Mulayen da aka yi amfani da su}} a wannan shafi:',
'templatesusedpreview'             => '{{PLURAL:$1|Mulun da aka yi amfani da shi|Mulayen da aka yi amfani da su}} cikin wannan rigya-gani:',
'template-protected'               => '(mai kariya)',
'template-semiprotected'           => '(da kariya gwalgwado)',
'hiddencategories'                 => 'Wannan shafi yana cikin {{PLURAL:$1|ɓoyayyen rukuni 1|ɓoyayyun rukunoni $1}}:',
'permissionserrorstext-withaction' => 'Ba kwa da izinin $2, don saboda {{PLURAL:$1|wannan dalili|waɗannan dalillai}}:',

# History pages
'viewpagelogs'           => 'Duba rajistan ayyukan wannan shafi',
'currentrev-asof'        => 'Zubin ƙarshe ga $1',
'revisionasof'           => 'Zubi na $1',
'previousrevision'       => '← Tsohon zubi',
'nextrevision'           => 'Zubi na gaba →',
'currentrevisionlink'    => 'Zubi na yanzu',
'cur'                    => 'na yanzu',
'last'                   => 'baya',
'histlegend'             => "Don nuna bambanci: a shaida zube-zuben da ake so a kwatanta sannan a latsa maɓallin da ke ƙasa.<br />
Fasali: '''({{int:cur}})''' = bambanci da zubi na yanzu, '''({{int:last}})''' = bambanci da zubi na baya, '''{{int:minoreditletter}}''' = ƙaramin gyara.",
'history-fieldset-title' => 'Shawagi cikin tarihi',
'histfirst'              => 'Na gaba',
'histlast'               => 'Na baya',

# Revision deletion
'rev-delundel'              => 'nuna/ɓoye',
'rev-showdeleted'           => 'nuna',
'revdelete-log'             => 'Dalili:',
'revdel-restore'            => 'sauya haske',
'revdelete-reasonotherlist' => 'Wani dalili',

# History merging
'mergehistory-reason' => 'Dalili:',

# Merge log
'revertmerge' => 'Ware',

# Diffs
'history-title'           => 'Tarihin sauye-sauyen "$1"',
'difference'              => '(Bambanci tsakanin zubi da zubi)',
'lineno'                  => 'Layi $1:',
'compareselectedversions' => 'Kwatanta zaɓaɓɓun zubi',
'editundo'                => 'Janyewa',

# Search results
'searchresults'             => 'Sakamakon bincike',
'searchresults-title'       => 'Sakamakon bincike na "$1"',
'searchresulttext'          => 'Don ƙarin bayani kan binciken {{SITENAME}}, duba [[{{MediaWiki:Helppage}}|{{int:help}}]]',
'searchsubtitle'            => 'Kun nemi \'\'\'[[:$1]]\'\'\'  ([[Special:Prefixindex/$1|duka shafuna masu farawa da "$1"]]{{int:pipe-separator}}[[Special:WhatLinksHere/$1|duka shafuna masu mahaɗi zuwa "$1"]])',
'searchsubtitleinvalid'     => "Kun nemi '''$1'''",
'notitlematches'            => 'Babu kan shafin da ya dace',
'notextmatches'             => 'Babu wani matanin da ya dace',
'prevn'                     => 'baya {{PLURAL:$1|$1}}',
'nextn'                     => 'gaba {{PLURAL:$1|$1}}',
'viewprevnext'              => 'Duba ($1 {{int:pipe-separator}} $2) ($3)',
'search-result-size'        => '$1 ({{PLURAL:$2|1 kalma|$2 kalmomi}})',
'search-redirect'           => '(turawa daga $1)',
'search-section'            => '(sashe $1)',
'search-suggest'            => 'Kuna nufin: $1',
'search-interwiki-caption'  => 'Shire-shire masu dangantaka',
'search-interwiki-default'  => 'Sakamakon $1:',
'search-interwiki-more'     => '(ƙari)',
'search-mwsuggest-enabled'  => 'Tare da shawarwari',
'search-mwsuggest-disabled' => 'Banda shawarwari',
'searchall'                 => 'duka',
'nonefound'                 => "'''Hattara''': Galibi wasu sararen suna ƙalilan kawai ake nemowa.
Ku gwada tare da amfani da \"all:\" don bincikar duka shafunan (har da shafunan muhawara, mulaye, d.s.), ko kuma ku yi amfani da sararin sunan da kuke so.",
'powersearch'               => 'Sahihin nema',
'powersearch-legend'        => 'Sahihin nema',
'powersearch-ns'            => 'Binciki sararen sunaye:',
'powersearch-redir'         => 'Nuna turawa gaba',
'powersearch-field'         => 'Neemo',
'powersearch-toggleall'     => 'Duka',

# Preferences page
'preferences'       => 'Saituttuka',
'mypreferences'     => 'Saituttukana',
'searchresultshead' => 'Nema',

# User rights
'userrights-reason' => 'Dalili:',

# Groups
'group-sysop' => 'Masu hukunci',

'grouppage-sysop' => '{{ns:project}}:Masu hukunci',

# User rights log
'rightslog' => "Rajistan bayar da izini ga ma'aikata",

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'gyara wannan shafi',

# Recent changes
'nchanges'                       => '{{PLURAL:$1|sauyi|sauye-sauye}} $1',
'recentchanges'                  => 'Sauye-sauyen baya-bayan nan',
'recentchanges-legend'           => 'Zaɓi na sauye-sauyen baya-bayan nan',
'recentchanges-feed-description' => 'Bi sawun sauye-sauyen ƙarshe na wikin da ke cikin wannan kwarare',
'rcnote'                         => "A nan ƙasa an nuna {{PLURAL:$1|sauyi '''1'''|sauye-sauyen ƙarshe '''$1'''}} a cikin {{PLURAL:$2|awowi 24 da suka shige|'''$2''' kwanaki}}, har zuwa $5, $4.",
'rclistfrom'                     => 'Nuna sabbin sauye-sauye tun daga $1',
'rcshowhideminor'                => '$1 ƙananen sauye-sauye',
'rcshowhidebots'                 => 'Rabuwat $1',
'rcshowhideliu'                  => "$1 Ma'aikata logaggi",
'rcshowhideanons'                => "$1 ma'aikata masu ɓoyayye suna",
'rcshowhidemine'                 => '$1 sauye-sauyena',
'rclinks'                        => 'Nuna sauye-sauye $1 na ƙarshe a cikin kwanaki $2 na baya<br />$3',
'diff'                           => 'bamban',
'hist'                           => 'Tarihi',
'hide'                           => 'Ɓoye',
'show'                           => 'Nuna',
'minoreditletter'                => 'm',
'newpageletter'                  => 'N',
'boteditletter'                  => 'b',
'rc-enhanced-expand'             => 'Nuna ƙananan bayannai (ana buƙatar JavaScript)',
'rc-enhanced-hide'               => 'Ɓoye ƙananan bayannai',

# Recent changes linked
'recentchangeslinked'         => 'Sauye-sauye masu dangantaka',
'recentchangeslinked-title'   => 'Bin sawun shafuna masu dangantaka da "$1"',
'recentchangeslinked-summary' => "Wannan jerin sauye-sauye ne da aka yi kan shafuna masu mahaɗi. Shafunan da ke cikin [[Special:Watchlist|jerin kan idonku]] an haɓaka su da '''gwaɓi'''",
'recentchangeslinked-page'    => 'Sunan shafi:',
'recentchangeslinked-to'      => 'Nuna sauye-sauyen shafunan da ke da mahaɗi da wannan shafin',

# Upload
'upload'            => 'Girke fayil',
'uploadlogpage'     => 'Rajistan girke fayiloli',
'filedesc'          => 'Taƙaici',
'fileuploadsummary' => 'Taƙaici:',
'uploadedimage'     => 'an girke "[[$1]]"',

# File description page
'filehist'                  => 'Tarihin fayil',
'filehist-help'             => 'ku Latsa rana/lokaci ku ga fayil yadda yake a wannan lokaci',
'filehist-deleteone'        => 'soke',
'filehist-current'          => 'na yanzu',
'filehist-datetime'         => 'Rana/Lokaci',
'filehist-thumb'            => 'Wadar sufa',
'filehist-thumbtext'        => 'Wadar sufa ta zubin $1',
'filehist-user'             => "Ma'aikaci",
'filehist-dimensions'       => 'Kusurwowi',
'filehist-comment'          => 'Bahasi',
'imagelinks'                => 'Amfani da fayil',
'linkstoimage'              => '{{PLURAL:$1|Wannan shafi yana|wanɗannan shafuna $1 suna}} amfani da wannan fayil:',
'sharedupload'              => 'Wannan fayil na da tushe daga $1 kuma wasu shire-shire suna iya amfani da shi.',
'uploadnewversion-linktext' => 'Ɗauki sabon zubi na wannan fayil',

# File reversion
'filerevert-comment' => 'Dalili:',

# File deletion
'filedelete-comment'          => 'Dalili:',
'filedelete-submit'           => 'Soke',
'filedelete-reason-otherlist' => 'Wani dalili',

# Statistics
'statistics' => 'Alƙalumma',

'brokenredirects-delete' => 'soke',

'withoutinterwiki-submit' => 'Nuna',

# Miscellaneous special pages
'nbytes'        => '{{PLURAL:$1|bayit|bayit}} $1',
'nmembers'      => '{{PLURAL:$1|mamba|mambobi}} $1',
'prefixindex'   => 'Duka shafuna masu ɗafa-goshi',
'newpages'      => 'Sabbin shafuna',
'move'          => 'Gusarwa',
'movethispage'  => 'Gusar da wannan shafi',
'pager-newer-n' => '{{PLURAL:$1|sabo 1|sabbi $1}}',
'pager-older-n' => '{{PLURAL:$1|tsoho 1|tsoffi $1}}',

# Book sources
'booksources'               => 'Littattafai maƙiblata',
'booksources-search-legend' => 'Nemo tushen littattafai',
'booksources-go'            => 'Mu je',

# Special:Log
'log' => 'Rajistoci ayyuka',

# Special:AllPages
'allpages'       => 'Duka shafuna',
'alphaindexline' => '$1 zuwa $2',
'prevpage'       => 'Shafi na baya ($1)',
'allpagesfrom'   => 'Nuna shafuna farawa daga:',
'allpagesto'     => 'Nuna shafuna har:',
'allarticles'    => 'Duka shafuna',
'allpagessubmit' => 'Mu je',

# Special:LinkSearch
'linksearch'    => 'Mahaɗan waje',
'linksearch-ns' => 'Sararin suna:',
'linksearch-ok' => 'Nema',

# Special:ListUsers
'listusers-submit' => 'Nuna',

# Special:Log/newusers
'newuserlogpage'          => 'Rajistan sabbin akwantoci',
'newuserlog-create-entry' => 'Sabon akwanti',

# Special:ListGroupRights
'listgrouprights-members' => '(jerin mambobi)',

# E-mail user
'emailuser' => "Aika wa wannan ma'aikaci imel",

# Watchlist
'watchlist'         => 'Jerina na bin sawu',
'mywatchlist'       => 'Jerina na bin sawu',
'addedwatchtext'    => "An daɗa shafin \"[[:\$1]]\" a cikin [[Special:Watchlist|jerinku na bin sawu]].
A nan ne kuma za a yi rajistan dukkan sauye-sauye ga shafin ko shafinsa na muhawara, kuma sunan shafin zai kasance '''mai gwaɓi''' a cikin [[Special:RecentChanges|jerin sauye-sauyen baya-bayan nan]] don sauƙin gani.",
'removedwatchtext'  => 'An fitar da shafin "[[:$1]]" daga [[Special:Watchlist|jerinku na bin sawu]].',
'watch'             => 'Bin sawu',
'watchthispage'     => 'Bin sawun wannan shafi',
'unwatch'           => 'Daina bin sawu',
'watchlist-details' => '{{PLURAL:$1|$1 shafi|$1 shafuna}} kan jerinku na bin sawu, banda shafunan mahawara.',
'wlshowlast'        => 'Nuna awowi $1 kwanaki $2 na ƙarshe $3',
'watchlist-options' => 'Saituttukan jerin bin sawu',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Bin sawun...',
'unwatching' => 'Daina bin sawu...',

# Delete
'deletepage'            => 'Soke shafin',
'delete-legend'         => 'Soke',
'confirmdeletetext'     => "Kuna kan hanyar soke wani shafi tare da duk tarihinsa. Ku tabbatar lalle kuna son yin hakan, tare da cewa kun fahimci sakamakon yin haka, kuma kuna yi ne da la'akari da [[{{MediaWiki:Policy-url}}|manufofi]].",
'actioncomplete'        => 'Aiki cikakke',
'deletedtext'           => 'An soke "$1".
Ku duba $2 ku ga rajistan soke-soke na baya-bayan nan.',
'deletedarticle'        => 'an soke "[[$1]]"',
'dellogpage'            => 'Rajistan sauye-sauye',
'deletecomment'         => 'Dalili:',
'deleteotherreason'     => 'Wani dalilin:',
'deletereasonotherlist' => 'Wani dalili',

# Rollback
'rollbacklink' => 'banyewa',

# Protect
'protectlogpage'              => 'Rajistan ayyukan kariya',
'protectedarticle'            => 'an kare "[[$1]]"',
'modifiedarticleprotection'   => 'an sauya matakin kariya na "[[$1]]"',
'protectcomment'              => 'Dalili:',
'protectexpiry'               => "Wa'adi:",
'protect_expiry_invalid'      => "Lokacin wa'adi bai da tasiri.",
'protect_expiry_old'          => "Lokacin wa'adi ya wuce.",
'protect-text'                => "Kuna iya duba tare da sauya matakin kariya na shafin '''$1'''.",
'protect-locked-access'       => "Akwantinku bai da izinin sauya matakan kariya na shafuna.
Ga dai matakan kariya na yanzu na shafin '''$1''':",
'protect-cascadeon'           => 'A yanzu an kiyaye wannan shafi saboda yana cikin {{PLURAL:$1|wannan shafi mai|waɗannan shafuna masu}} kariya mai zuzzubowa.
Kuna iya sake wa wannan shafi matakin kariya, amma hakan ba zai yi tasiri ga kariya mai zuzzubowa ba.',
'protect-default'             => "Lamunce wa duka ma'aikata",
'protect-fallback'            => 'Ana buƙatar izinin "$1"',
'protect-level-autoconfirmed' => "Hana sabbin ma'aikata da ma'aikata maras akwanti",
'protect-level-sysop'         => 'Mahukunta kawai',
'protect-summary-cascade'     => 'zuzzubawa',
'protect-expiring'            => "Wa'adi ran $1 (UTC)",
'protect-cascade'             => 'A kiyaye shafunan da aka haɗa cikin wannan shafi (kariya mai zuzzubowa)',
'protect-cantedit'            => 'Ba ku iya sauya matakan kariya na wannan shafi, saboda ba ku da izinin yi masa gyara.',
'protect-otherreason-op'      => 'Wani dalili',
'restriction-type'            => 'Izini:',
'restriction-level'           => 'Matakin kangewa:',

# Restrictions (nouns)
'restriction-move'   => 'Gusarwa',
'restriction-create' => 'Ƙirƙira',

# Undelete
'undeletelink'           => 'duba/maido da',
'undeletecomment'        => 'Dalili:',
'undeletedarticle'       => 'an mayar da "[[$1]]"',
'undelete-search-submit' => 'Nema',

# Namespace form on various pages
'namespace'      => 'Sararin suna:',
'invert'         => 'Jirkita kamu',
'blanknamespace' => '(Babba)',

# Contributions
'contributions'       => "Gudummuwar ma'aikaci",
'contributions-title' => "Jerin gudummuwar ma'aikaci $1",
'mycontris'           => 'Gudummawata',
'contribsub2'         => 'Na $1 ($2)',
'uctop'               => '(sama)',
'month'               => 'Tun daga wata (da gabansa):',
'year'                => 'Tun daga shekara (da gabanta):',

'sp-contributions-newbies'  => 'Nuna gudummuwar sabbin akwantoci kawai',
'sp-contributions-blocklog' => 'rajistan hani',
'sp-contributions-search'   => 'Nemo gudummuwa',
'sp-contributions-username' => "Adireshin IP ko sunan ma'aikaci:",
'sp-contributions-submit'   => 'Nemo',

# What links here
'whatlinkshere'            => 'Mahaɗan wannan shafi',
'whatlinkshere-title'      => 'Shafuna masu mahaɗi da "$1"',
'whatlinkshere-page'       => 'Shafi:',
'linkshere'                => "Waɗannan shafuna sun haɗu da '''[[:$1]]''':",
'isredirect'               => 'shafin turawa',
'istemplate'               => 'gami',
'isimage'                  => 'majigi shigagge',
'whatlinkshere-prev'       => '{{PLURAL:$1|na baya|na baya $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|na gaba|na gaba $1}}',
'whatlinkshere-links'      => '← mahaɗai',
'whatlinkshere-hideredirs' => '$1 turawa',
'whatlinkshere-hidetrans'  => '$1 game-game',
'whatlinkshere-hidelinks'  => '$1 mahaɗai',
'whatlinkshere-filters'    => 'Matatai',

# Block/unblock
'blockip'                  => "Hana ma'aikaci",
'ipbreason'                => 'Dalili:',
'ipbreasonotherlist'       => 'Wani dalili',
'ipboptions'               => 'awa 2:2 hours,kwana 1:1 day,kwana 3:3 days,mako 1:1 week,mako 2:2 weeks,wata 1:1 month,wata 3:3 months,wata 6:6 months,shekara 1:1 year,illa masha allahu:infinite',
'ipblocklist'              => "Adireshin IP da ma'aikatan da aka hana",
'ipblocklist-submit'       => 'Nema',
'blocklink'                => 'Hanawa',
'unblocklink'              => 'karɓa',
'change-blocklink'         => 'Canza hanawa',
'contribslink'             => 'Gudummuwa',
'blocklogpage'             => 'Rajistan hani',
'blocklogentry'            => "an hana [[$1]] da wa'adin $2 $3",
'unblocklogentry'          => 'an lamunce wa $1',
'block-log-flags-nocreate' => 'babu damar buɗa sabon akwanti',

# Move page
'movepagetext'     => "Ku yi amfani da fom na ƙasa don sake sunan shafin, tare da mayar da duka tarihinsa ga sabon sunan.
Tsohon sunan zai nuna sabon sunan.
Kuna iya sabunta dukan mahaɗai da ke nuna tsohon sunan otomatikali.
Idan ba ku yi haka ba, ku duba [[Special:DoubleRedirects|rikitattun mahaɗai]] ko [[Special:BrokenRedirects|katsattsun mahaɗai]].
Ku ke da nauyin tabbatar dukan mahaɗai suna nuna inda ya kamata.

Wannan shafi '''ba''' za a sake masa suna ba idan akwai wani shafi mai sabon sunan, sai fa idan shafin kwango ne ko yana da mahaɗi kuma bai da tarihin sauye-sauye.
Haka yana nufin za ku iya mayar wa wani shafi tsohon sunansa idan kuka yi kwata, kuma ba za ku iya kwatse wani tsayayyan shafi ba.

'''Hattara!'''
Yin haka na iya zama wani gagarumin sauyi ga shafi mai farin jini;
Don Allah ku tabbatar kun fahimci sakamakon yin hakan.",
'movepagetalktext' => "Za a gusar da dangantaccen shafin muhawara otomatikali tare da '''sai fa idan''' kinta.
*Akwai wani shafin muhawara wanda ba kango ba a ƙarƙashin sabon sunan, ko
*Kun soke zaɓen ɗan ɗaki na ƙasa.

A waɗannan halaye, dole ku gusar ko ku game shafin da hannu, idan kuna so.",
'movearticle'      => 'Gusar da shafin:',
'newtitle'         => 'Zuwa sabon kai:',
'move-watch'       => 'Bin sawun wannan shafi',
'movepagebtn'      => 'Gusar da shafin',
'pagemovedsub'     => 'Gusarwa ta cika',
'movepage-moved'   => '\'\'\'"$1" an gusar da shi zuwa "$2"\'\'\'',
'articleexists'    => 'Akwai wani shafi mai wannan suna, koko sunan da kuka zaɓa ba shi da tasiri.
Don Allah ku zaɓi wani suna.',
'talkexists'       => "'''An gusar da shafin shi kansa, amma an kasa gusar da dangantaccen shafin muhawarar, don akwai wani sahfin mai amfani da sunansa.
Don Allah ku game su da hannu.'''",
'movedto'          => 'an gusar zuwa',
'movetalk'         => 'Gusar da shafin mahawara mai alaƙa',
'1movedto2'        => 'an gusar da [[$1]] zuwa [[$2]]',
'1movedto2_redir'  => 'an gusar da [[$1]] zuwa [[$2]] ta hanyar soke turawa',
'movelogpage'      => 'Rajistan gushe-gushe',
'movereason'       => 'Dalili:',
'revertmove'       => 'koma',

# Export
'export' => 'Tsamo shafuna',

# Thumbnails
'thumbnail-more' => 'Faɗaɗa',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Shafinku na marhabin',
'tooltip-pt-mytalk'               => 'Shafinku na mahawara',
'tooltip-pt-preferences'          => 'Saituttukanku',
'tooltip-pt-watchlist'            => 'Jerin shafunan da kuke bin sawun sauye-sauyensu',
'tooltip-pt-mycontris'            => 'Jerin gudummuwarku',
'tooltip-pt-login'                => 'Ana shawarar ku shiga akwantinku, amma ba dole ba ne',
'tooltip-pt-logout'               => 'Ban kwana',
'tooltip-ca-talk'                 => 'Mahawara kan shafin bayannai',
'tooltip-ca-edit'                 => 'Ana iya gyara wannan shafi
A yi amfani da maɓallin rigya-gani kafin a adina',
'tooltip-ca-addsection'           => 'Fara sabon sashe',
'tooltip-ca-viewsource'           => 'Wannan shafi yana da kariya.
Kuna iya duba tushensa.',
'tooltip-ca-history'              => 'Tsoffin sufofin wannan shafi',
'tooltip-ca-protect'              => 'Kare wannan shafi',
'tooltip-ca-delete'               => 'Soke wannan shafi',
'tooltip-ca-move'                 => 'Gusar da wannan shafi',
'tooltip-ca-watch'                => 'A daɗa wannan shafi cikin jerina na bin sawu',
'tooltip-ca-unwatch'              => 'Ku soke wannan shafi daga jerinku na bin sawu',
'tooltip-search'                  => 'Binciko {{SITENAME}}',
'tooltip-search-go'               => 'A je ga shafi mai wannan suna idan akwai shi',
'tooltip-search-fulltext'         => 'Binciki shafuna masu wannan matani',
'tooltip-n-mainpage'              => 'Duba shafin Marhabin',
'tooltip-n-mainpage-description'  => 'Duba shafin marhabin',
'tooltip-n-portal'                => 'A game da wannan shiri, abinda za a iya yi, ina za a samu abubuwa',
'tooltip-n-currentevents'         => 'Nemo bayannai kan yanayin labarun yau',
'tooltip-n-recentchanges'         => 'Jerin sabin sauye-sauye a wannan Wiki',
'tooltip-n-randompage'            => 'Nuno wani shafi da ka',
'tooltip-n-help'                  => 'Nuno taimako',
'tooltip-t-whatlinkshere'         => 'Jerin duk shafunan Wiki da ke da mahaɗi a nan',
'tooltip-t-recentchangeslinked'   => 'Sauye-sauyen baya-bayan nan a shafuna masu mahaɗi daga wannan shafi',
'tooltip-feed-rss'                => 'Kwararen RSS na wannan shafi',
'tooltip-feed-atom'               => 'Kwararen Atom na wannan shafi',
'tooltip-t-contributions'         => "Duba jerin gudummuwar wannan ma'aikaci",
'tooltip-t-emailuser'             => "Aika wa wannan ma'aikaci imel",
'tooltip-t-upload'                => 'Girke fayiloli',
'tooltip-t-specialpages'          => 'Jerin duk shafuna na musamman',
'tooltip-t-print'                 => 'Wannan shafi a sufar bugawa',
'tooltip-t-permalink'             => 'Mahaɗin dindindin zuwa ga zubin baya na wannan shafi',
'tooltip-ca-nstab-main'           => 'Duba shafin bayannai',
'tooltip-ca-nstab-user'           => "Duba shafin ma'aikaci",
'tooltip-ca-nstab-special'        => 'Wannan shafi ne na musamman, ba za ku iya yi masa gyara ba',
'tooltip-ca-nstab-project'        => 'Duba shafin shirin',
'tooltip-ca-nstab-image'          => 'Duba shafin fayil',
'tooltip-ca-nstab-template'       => 'Duba mulun',
'tooltip-ca-nstab-category'       => 'Duba shafin rukuni',
'tooltip-minoredit'               => 'Alamta wannan a matsayin ƙaramin gyara',
'tooltip-save'                    => 'Ku adana sauye-sauyenku',
'tooltip-preview'                 => 'Ku tantance sauye-sauyenku, don Allah ku yi amfani da wannan kafin ku adana su:',
'tooltip-diff'                    => 'Na nuna sauye-sauyen da kuka yi wa matanin',
'tooltip-compareselectedversions' => 'Duba bambanci tsakanin zaɓaɓɓun zubi biyu na wannan shafi',
'tooltip-watch'                   => 'Ku daɗa wannan shafi cikin jerinku na bin sawu',
'tooltip-rollback'                => '"Banyewa" tana soke sauye-sauyen da mutunen baya ya yi da kiliki guda',
'tooltip-undo'                    => '"Janyewa" tana soke wannan gyaran ta kuma buɗa fom kin gyara mai rigya-gani.
Tana ba da damar bayyana dalilin soke gyaran.',

# Browsing diffs
'previousdiff' => 'Sauyin baya',
'nextdiff'     => 'Gyaran gaba →',

# Media information
'file-info-size' => 'pikisal $1 × $2, girman fayil: $3, irin MIME: $4',
'file-nohires'   => '<small>Babu wata babbar saƙa.</small>',
'svg-long-desc'  => 'Fayil kin SVG, saƙar fikisal $1 x $2, girman fayil: $3',
'show-big-image' => 'Cikakkar saƙa',

# Special:NewFiles
'ilsubmit' => 'Nema',

# Bad image list
'bad_image_list' => 'Fasalin yana kamar haka:

Za a lura da layukan jeri kawai (masu farawa da *).
Zaren farko a kan layi ya kamata ya nuna fayil maras kyau.
Sauran mahaɗai a kan layin keɓaɓɓu ne, wato zuwa ga shafuna inda fayil kin zai iya kasancewa.',

# Metadata
'metadata'          => 'bayannan meta',
'metadata-help'     => 'Wannan fayil ya ƙumshi ƙarin bayani daga kyamarar dijita ko sikanan da aka yi amfani da su.
Idan an sauya fayil kin, to wasu bayannan na ainahi ba za su fito ba sosai a cikin sabon fayil kin.',
'metadata-expand'   => 'Nuna ƙananan bayannai',
'metadata-collapse' => 'Ɓoye ƙananan bayannai',
'metadata-fields'   => 'Gurabun bayannan meta na EXIF da ke jere cikin wannan saƙo, za a saka su ne cikin shafin zayyana majigin, idan aka taƙaita jadawalin bayannan metan.
 Wasu gurabun za a ɓoye su bisa manufa.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally'      => 'Gyara wannan fayil da wani safuwai daban',
'edit-externally-help' => '(Duba [//www.mediawiki.org/wiki/Manual:External_editors bayannan shimfiɗawa] don ƙarin bayani)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'duka',
'namespacesall' => 'duka',
'monthsall'     => 'duka',

# Watchlist editing tools
'watchlisttools-view' => 'Duba sauye-sauyen da suka dace',
'watchlisttools-edit' => 'Duba kuma gyara jerin bin sawu',
'watchlisttools-raw'  => 'Gyara jerin bin sawu',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Nema',

# Special:SpecialPages
'specialpages' => 'Shafuna na musamman',

);
